# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[_builtins.str],
                 allow_merge_on_skipped_pipeline: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_email_domains_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extra_shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_restriction_ranges: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 lfs_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 membership_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 mentions_disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 only_allow_merge_if_all_discussions_are_resolved: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_allow_merge_if_pipeline_succeeds: Optional[pulumi.Input[_builtins.bool]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.int]] = None,
                 permanently_remove_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_forking_outside_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_sharing_groups_outside_hierarchy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 push_rules: Optional[pulumi.Input['GroupPushRulesArgs']] = None,
                 request_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 share_with_group_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 subgroup_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 visibility_level: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_access_level: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[_builtins.str] path: The path of the group.
        :param pulumi.Input[_builtins.bool] allow_merge_on_skipped_pipeline: Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_domains_lists: A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Default to Auto DevOps pipeline for all projects within this group.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        :param pulumi.Input[_builtins.str] default_branch: Initial default branch name.
        :param pulumi.Input[_builtins.int] default_branch_protection: See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        :param pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs'] default_branch_protection_defaults: The default branch protection defaults
        :param pulumi.Input[_builtins.str] description: The group's description.
        :param pulumi.Input[_builtins.bool] emails_enabled: Enable email notifications.
        :param pulumi.Input[_builtins.int] extra_shared_runners_minutes_limit: Can be set by administrators only. Additional CI/CD minutes for this group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_restriction_ranges: A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        :param pulumi.Input[_builtins.bool] lfs_enabled: Enable/disable Large File Storage (LFS) for the projects in this group.
        :param pulumi.Input[_builtins.bool] membership_lock: Users cannot be added to projects in this group.
        :param pulumi.Input[_builtins.bool] mentions_disabled: Disable the capability of a group from getting mentioned.
        :param pulumi.Input[_builtins.str] name: The name of the group.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_all_discussions_are_resolved: Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_pipeline_succeeds: Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] parent_id: Id of the parent group (creates a nested group).
        :param pulumi.Input[_builtins.bool] permanently_remove_on_delete: Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        :param pulumi.Input[_builtins.bool] prevent_forking_outside_group: Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        :param pulumi.Input[_builtins.bool] prevent_sharing_groups_outside_hierarchy: Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        :param pulumi.Input[_builtins.str] project_creation_level: Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        :param pulumi.Input['GroupPushRulesArgs'] push_rules: Push rules for the group.
        :param pulumi.Input[_builtins.bool] request_access_enabled: Allow users to request member access.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: Require all users in this group to setup Two-factor authentication.
        :param pulumi.Input[_builtins.bool] share_with_group_lock: Prevent sharing a project with another group within this group.
        :param pulumi.Input[_builtins.int] shared_runners_minutes_limit: Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        :param pulumi.Input[_builtins.str] shared_runners_setting: Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        :param pulumi.Input[_builtins.str] subgroup_creation_level: Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        :param pulumi.Input[_builtins.str] visibility_level: The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        :param pulumi.Input[_builtins.str] wiki_access_level: The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        pulumi.set(__self__, "path", path)
        if allow_merge_on_skipped_pipeline is not None:
            pulumi.set(__self__, "allow_merge_on_skipped_pipeline", allow_merge_on_skipped_pipeline)
        if allowed_email_domains_lists is not None:
            pulumi.set(__self__, "allowed_email_domains_lists", allowed_email_domains_lists)
        if auto_devops_enabled is not None:
            pulumi.set(__self__, "auto_devops_enabled", auto_devops_enabled)
        if avatar is not None:
            pulumi.set(__self__, "avatar", avatar)
        if avatar_hash is not None:
            pulumi.set(__self__, "avatar_hash", avatar_hash)
        if default_branch is not None:
            pulumi.set(__self__, "default_branch", default_branch)
        if default_branch_protection is not None:
            warnings.warn("""Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""", DeprecationWarning)
            pulumi.log.warn("""default_branch_protection is deprecated: Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""")
        if default_branch_protection is not None:
            pulumi.set(__self__, "default_branch_protection", default_branch_protection)
        if default_branch_protection_defaults is not None:
            pulumi.set(__self__, "default_branch_protection_defaults", default_branch_protection_defaults)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if emails_enabled is not None:
            pulumi.set(__self__, "emails_enabled", emails_enabled)
        if extra_shared_runners_minutes_limit is not None:
            pulumi.set(__self__, "extra_shared_runners_minutes_limit", extra_shared_runners_minutes_limit)
        if ip_restriction_ranges is not None:
            pulumi.set(__self__, "ip_restriction_ranges", ip_restriction_ranges)
        if lfs_enabled is not None:
            pulumi.set(__self__, "lfs_enabled", lfs_enabled)
        if membership_lock is not None:
            pulumi.set(__self__, "membership_lock", membership_lock)
        if mentions_disabled is not None:
            pulumi.set(__self__, "mentions_disabled", mentions_disabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if only_allow_merge_if_all_discussions_are_resolved is not None:
            pulumi.set(__self__, "only_allow_merge_if_all_discussions_are_resolved", only_allow_merge_if_all_discussions_are_resolved)
        if only_allow_merge_if_pipeline_succeeds is not None:
            pulumi.set(__self__, "only_allow_merge_if_pipeline_succeeds", only_allow_merge_if_pipeline_succeeds)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if permanently_remove_on_delete is not None:
            pulumi.set(__self__, "permanently_remove_on_delete", permanently_remove_on_delete)
        if prevent_forking_outside_group is not None:
            pulumi.set(__self__, "prevent_forking_outside_group", prevent_forking_outside_group)
        if prevent_sharing_groups_outside_hierarchy is not None:
            pulumi.set(__self__, "prevent_sharing_groups_outside_hierarchy", prevent_sharing_groups_outside_hierarchy)
        if project_creation_level is not None:
            pulumi.set(__self__, "project_creation_level", project_creation_level)
        if push_rules is not None:
            pulumi.set(__self__, "push_rules", push_rules)
        if request_access_enabled is not None:
            pulumi.set(__self__, "request_access_enabled", request_access_enabled)
        if require_two_factor_authentication is not None:
            pulumi.set(__self__, "require_two_factor_authentication", require_two_factor_authentication)
        if share_with_group_lock is not None:
            pulumi.set(__self__, "share_with_group_lock", share_with_group_lock)
        if shared_runners_minutes_limit is not None:
            pulumi.set(__self__, "shared_runners_minutes_limit", shared_runners_minutes_limit)
        if shared_runners_setting is not None:
            pulumi.set(__self__, "shared_runners_setting", shared_runners_setting)
        if subgroup_creation_level is not None:
            pulumi.set(__self__, "subgroup_creation_level", subgroup_creation_level)
        if two_factor_grace_period is not None:
            pulumi.set(__self__, "two_factor_grace_period", two_factor_grace_period)
        if visibility_level is not None:
            pulumi.set(__self__, "visibility_level", visibility_level)
        if wiki_access_level is not None:
            pulumi.set(__self__, "wiki_access_level", wiki_access_level)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        The path of the group.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="allowMergeOnSkippedPipeline")
    def allow_merge_on_skipped_pipeline(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        """
        return pulumi.get(self, "allow_merge_on_skipped_pipeline")

    @allow_merge_on_skipped_pipeline.setter
    def allow_merge_on_skipped_pipeline(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_merge_on_skipped_pipeline", value)

    @_builtins.property
    @pulumi.getter(name="allowedEmailDomainsLists")
    def allowed_email_domains_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        """
        return pulumi.get(self, "allowed_email_domains_lists")

    @allowed_email_domains_lists.setter
    def allowed_email_domains_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_email_domains_lists", value)

    @_builtins.property
    @pulumi.getter(name="autoDevopsEnabled")
    def auto_devops_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Default to Auto DevOps pipeline for all projects within this group.
        """
        return pulumi.get(self, "auto_devops_enabled")

    @auto_devops_enabled.setter
    def auto_devops_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_devops_enabled", value)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A local path to the avatar image to upload. **Note**: not available for imported resources.
        """
        return pulumi.get(self, "avatar")

    @avatar.setter
    def avatar(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar", value)

    @_builtins.property
    @pulumi.getter(name="avatarHash")
    def avatar_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        """
        return pulumi.get(self, "avatar_hash")

    @avatar_hash.setter
    def avatar_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar_hash", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Initial default branch name.
        """
        return pulumi.get(self, "default_branch")

    @default_branch.setter
    def default_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_branch", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    @_utilities.deprecated("""Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""")
    def default_branch_protection(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        """
        return pulumi.get(self, "default_branch_protection")

    @default_branch_protection.setter
    def default_branch_protection(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_branch_protection", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtectionDefaults")
    def default_branch_protection_defaults(self) -> Optional[pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs']]:
        """
        The default branch protection defaults
        """
        return pulumi.get(self, "default_branch_protection_defaults")

    @default_branch_protection_defaults.setter
    def default_branch_protection_defaults(self, value: Optional[pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs']]):
        pulumi.set(self, "default_branch_protection_defaults", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group's description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="emailsEnabled")
    def emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable email notifications.
        """
        return pulumi.get(self, "emails_enabled")

    @emails_enabled.setter
    def emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="extraSharedRunnersMinutesLimit")
    def extra_shared_runners_minutes_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Can be set by administrators only. Additional CI/CD minutes for this group.
        """
        return pulumi.get(self, "extra_shared_runners_minutes_limit")

    @extra_shared_runners_minutes_limit.setter
    def extra_shared_runners_minutes_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "extra_shared_runners_minutes_limit", value)

    @_builtins.property
    @pulumi.getter(name="ipRestrictionRanges")
    def ip_restriction_ranges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        """
        return pulumi.get(self, "ip_restriction_ranges")

    @ip_restriction_ranges.setter
    def ip_restriction_ranges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_restriction_ranges", value)

    @_builtins.property
    @pulumi.getter(name="lfsEnabled")
    def lfs_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable/disable Large File Storage (LFS) for the projects in this group.
        """
        return pulumi.get(self, "lfs_enabled")

    @lfs_enabled.setter
    def lfs_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "lfs_enabled", value)

    @_builtins.property
    @pulumi.getter(name="membershipLock")
    def membership_lock(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Users cannot be added to projects in this group.
        """
        return pulumi.get(self, "membership_lock")

    @membership_lock.setter
    def membership_lock(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "membership_lock", value)

    @_builtins.property
    @pulumi.getter(name="mentionsDisabled")
    def mentions_disabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable the capability of a group from getting mentioned.
        """
        return pulumi.get(self, "mentions_disabled")

    @mentions_disabled.setter
    def mentions_disabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mentions_disabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="onlyAllowMergeIfAllDiscussionsAreResolved")
    def only_allow_merge_if_all_discussions_are_resolved(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        """
        return pulumi.get(self, "only_allow_merge_if_all_discussions_are_resolved")

    @only_allow_merge_if_all_discussions_are_resolved.setter
    def only_allow_merge_if_all_discussions_are_resolved(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_allow_merge_if_all_discussions_are_resolved", value)

    @_builtins.property
    @pulumi.getter(name="onlyAllowMergeIfPipelineSucceeds")
    def only_allow_merge_if_pipeline_succeeds(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        """
        return pulumi.get(self, "only_allow_merge_if_pipeline_succeeds")

    @only_allow_merge_if_pipeline_succeeds.setter
    def only_allow_merge_if_pipeline_succeeds(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_allow_merge_if_pipeline_succeeds", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Id of the parent group (creates a nested group).
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter(name="permanentlyRemoveOnDelete")
    def permanently_remove_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        """
        return pulumi.get(self, "permanently_remove_on_delete")

    @permanently_remove_on_delete.setter
    def permanently_remove_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "permanently_remove_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="preventForkingOutsideGroup")
    def prevent_forking_outside_group(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        """
        return pulumi.get(self, "prevent_forking_outside_group")

    @prevent_forking_outside_group.setter
    def prevent_forking_outside_group(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prevent_forking_outside_group", value)

    @_builtins.property
    @pulumi.getter(name="preventSharingGroupsOutsideHierarchy")
    def prevent_sharing_groups_outside_hierarchy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        """
        return pulumi.get(self, "prevent_sharing_groups_outside_hierarchy")

    @prevent_sharing_groups_outside_hierarchy.setter
    def prevent_sharing_groups_outside_hierarchy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prevent_sharing_groups_outside_hierarchy", value)

    @_builtins.property
    @pulumi.getter(name="projectCreationLevel")
    def project_creation_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        """
        return pulumi.get(self, "project_creation_level")

    @project_creation_level.setter
    def project_creation_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_creation_level", value)

    @_builtins.property
    @pulumi.getter(name="pushRules")
    def push_rules(self) -> Optional[pulumi.Input['GroupPushRulesArgs']]:
        """
        Push rules for the group.
        """
        return pulumi.get(self, "push_rules")

    @push_rules.setter
    def push_rules(self, value: Optional[pulumi.Input['GroupPushRulesArgs']]):
        pulumi.set(self, "push_rules", value)

    @_builtins.property
    @pulumi.getter(name="requestAccessEnabled")
    def request_access_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow users to request member access.
        """
        return pulumi.get(self, "request_access_enabled")

    @request_access_enabled.setter
    def request_access_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "request_access_enabled", value)

    @_builtins.property
    @pulumi.getter(name="requireTwoFactorAuthentication")
    def require_two_factor_authentication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require all users in this group to setup Two-factor authentication.
        """
        return pulumi.get(self, "require_two_factor_authentication")

    @require_two_factor_authentication.setter
    def require_two_factor_authentication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_two_factor_authentication", value)

    @_builtins.property
    @pulumi.getter(name="shareWithGroupLock")
    def share_with_group_lock(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Prevent sharing a project with another group within this group.
        """
        return pulumi.get(self, "share_with_group_lock")

    @share_with_group_lock.setter
    def share_with_group_lock(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "share_with_group_lock", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutesLimit")
    def shared_runners_minutes_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        """
        return pulumi.get(self, "shared_runners_minutes_limit")

    @shared_runners_minutes_limit.setter
    def shared_runners_minutes_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "shared_runners_minutes_limit", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersSetting")
    def shared_runners_setting(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        """
        return pulumi.get(self, "shared_runners_setting")

    @shared_runners_setting.setter
    def shared_runners_setting(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_runners_setting", value)

    @_builtins.property
    @pulumi.getter(name="subgroupCreationLevel")
    def subgroup_creation_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        """
        return pulumi.get(self, "subgroup_creation_level")

    @subgroup_creation_level.setter
    def subgroup_creation_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subgroup_creation_level", value)

    @_builtins.property
    @pulumi.getter(name="twoFactorGracePeriod")
    def two_factor_grace_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        """
        return pulumi.get(self, "two_factor_grace_period")

    @two_factor_grace_period.setter
    def two_factor_grace_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "two_factor_grace_period", value)

    @_builtins.property
    @pulumi.getter(name="visibilityLevel")
    def visibility_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        """
        return pulumi.get(self, "visibility_level")

    @visibility_level.setter
    def visibility_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "visibility_level", value)

    @_builtins.property
    @pulumi.getter(name="wikiAccessLevel")
    def wiki_access_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        return pulumi.get(self, "wiki_access_level")

    @wiki_access_level.setter
    def wiki_access_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "wiki_access_level", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 allow_merge_on_skipped_pipeline: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_email_domains_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_url: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extra_shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 full_name: Optional[pulumi.Input[_builtins.str]] = None,
                 full_path: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_restriction_ranges: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 lfs_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 membership_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 mentions_disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 only_allow_merge_if_all_discussions_are_resolved: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_allow_merge_if_pipeline_succeeds: Optional[pulumi.Input[_builtins.bool]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.int]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_remove_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_forking_outside_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_sharing_groups_outside_hierarchy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 push_rules: Optional[pulumi.Input['GroupPushRulesArgs']] = None,
                 request_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 runners_token: Optional[pulumi.Input[_builtins.str]] = None,
                 share_with_group_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 subgroup_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 visibility_level: Optional[pulumi.Input[_builtins.str]] = None,
                 web_url: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_access_level: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[_builtins.bool] allow_merge_on_skipped_pipeline: Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_domains_lists: A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Default to Auto DevOps pipeline for all projects within this group.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        :param pulumi.Input[_builtins.str] avatar_url: The URL of the avatar image.
        :param pulumi.Input[_builtins.str] default_branch: Initial default branch name.
        :param pulumi.Input[_builtins.int] default_branch_protection: See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        :param pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs'] default_branch_protection_defaults: The default branch protection defaults
        :param pulumi.Input[_builtins.str] description: The group's description.
        :param pulumi.Input[_builtins.bool] emails_enabled: Enable email notifications.
        :param pulumi.Input[_builtins.int] extra_shared_runners_minutes_limit: Can be set by administrators only. Additional CI/CD minutes for this group.
        :param pulumi.Input[_builtins.str] full_name: The full name of the group.
        :param pulumi.Input[_builtins.str] full_path: The full path of the group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_restriction_ranges: A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        :param pulumi.Input[_builtins.bool] lfs_enabled: Enable/disable Large File Storage (LFS) for the projects in this group.
        :param pulumi.Input[_builtins.bool] membership_lock: Users cannot be added to projects in this group.
        :param pulumi.Input[_builtins.bool] mentions_disabled: Disable the capability of a group from getting mentioned.
        :param pulumi.Input[_builtins.str] name: The name of the group.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_all_discussions_are_resolved: Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_pipeline_succeeds: Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] parent_id: Id of the parent group (creates a nested group).
        :param pulumi.Input[_builtins.str] path: The path of the group.
        :param pulumi.Input[_builtins.bool] permanently_remove_on_delete: Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        :param pulumi.Input[_builtins.bool] prevent_forking_outside_group: Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        :param pulumi.Input[_builtins.bool] prevent_sharing_groups_outside_hierarchy: Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        :param pulumi.Input[_builtins.str] project_creation_level: Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        :param pulumi.Input['GroupPushRulesArgs'] push_rules: Push rules for the group.
        :param pulumi.Input[_builtins.bool] request_access_enabled: Allow users to request member access.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: Require all users in this group to setup Two-factor authentication.
        :param pulumi.Input[_builtins.str] runners_token: The group level registration token to use during runner setup.
        :param pulumi.Input[_builtins.bool] share_with_group_lock: Prevent sharing a project with another group within this group.
        :param pulumi.Input[_builtins.int] shared_runners_minutes_limit: Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        :param pulumi.Input[_builtins.str] shared_runners_setting: Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        :param pulumi.Input[_builtins.str] subgroup_creation_level: Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        :param pulumi.Input[_builtins.str] visibility_level: The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        :param pulumi.Input[_builtins.str] web_url: Web URL of the group.
        :param pulumi.Input[_builtins.str] wiki_access_level: The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        if allow_merge_on_skipped_pipeline is not None:
            pulumi.set(__self__, "allow_merge_on_skipped_pipeline", allow_merge_on_skipped_pipeline)
        if allowed_email_domains_lists is not None:
            pulumi.set(__self__, "allowed_email_domains_lists", allowed_email_domains_lists)
        if auto_devops_enabled is not None:
            pulumi.set(__self__, "auto_devops_enabled", auto_devops_enabled)
        if avatar is not None:
            pulumi.set(__self__, "avatar", avatar)
        if avatar_hash is not None:
            pulumi.set(__self__, "avatar_hash", avatar_hash)
        if avatar_url is not None:
            pulumi.set(__self__, "avatar_url", avatar_url)
        if default_branch is not None:
            pulumi.set(__self__, "default_branch", default_branch)
        if default_branch_protection is not None:
            warnings.warn("""Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""", DeprecationWarning)
            pulumi.log.warn("""default_branch_protection is deprecated: Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""")
        if default_branch_protection is not None:
            pulumi.set(__self__, "default_branch_protection", default_branch_protection)
        if default_branch_protection_defaults is not None:
            pulumi.set(__self__, "default_branch_protection_defaults", default_branch_protection_defaults)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if emails_enabled is not None:
            pulumi.set(__self__, "emails_enabled", emails_enabled)
        if extra_shared_runners_minutes_limit is not None:
            pulumi.set(__self__, "extra_shared_runners_minutes_limit", extra_shared_runners_minutes_limit)
        if full_name is not None:
            pulumi.set(__self__, "full_name", full_name)
        if full_path is not None:
            pulumi.set(__self__, "full_path", full_path)
        if ip_restriction_ranges is not None:
            pulumi.set(__self__, "ip_restriction_ranges", ip_restriction_ranges)
        if lfs_enabled is not None:
            pulumi.set(__self__, "lfs_enabled", lfs_enabled)
        if membership_lock is not None:
            pulumi.set(__self__, "membership_lock", membership_lock)
        if mentions_disabled is not None:
            pulumi.set(__self__, "mentions_disabled", mentions_disabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if only_allow_merge_if_all_discussions_are_resolved is not None:
            pulumi.set(__self__, "only_allow_merge_if_all_discussions_are_resolved", only_allow_merge_if_all_discussions_are_resolved)
        if only_allow_merge_if_pipeline_succeeds is not None:
            pulumi.set(__self__, "only_allow_merge_if_pipeline_succeeds", only_allow_merge_if_pipeline_succeeds)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if permanently_remove_on_delete is not None:
            pulumi.set(__self__, "permanently_remove_on_delete", permanently_remove_on_delete)
        if prevent_forking_outside_group is not None:
            pulumi.set(__self__, "prevent_forking_outside_group", prevent_forking_outside_group)
        if prevent_sharing_groups_outside_hierarchy is not None:
            pulumi.set(__self__, "prevent_sharing_groups_outside_hierarchy", prevent_sharing_groups_outside_hierarchy)
        if project_creation_level is not None:
            pulumi.set(__self__, "project_creation_level", project_creation_level)
        if push_rules is not None:
            pulumi.set(__self__, "push_rules", push_rules)
        if request_access_enabled is not None:
            pulumi.set(__self__, "request_access_enabled", request_access_enabled)
        if require_two_factor_authentication is not None:
            pulumi.set(__self__, "require_two_factor_authentication", require_two_factor_authentication)
        if runners_token is not None:
            pulumi.set(__self__, "runners_token", runners_token)
        if share_with_group_lock is not None:
            pulumi.set(__self__, "share_with_group_lock", share_with_group_lock)
        if shared_runners_minutes_limit is not None:
            pulumi.set(__self__, "shared_runners_minutes_limit", shared_runners_minutes_limit)
        if shared_runners_setting is not None:
            pulumi.set(__self__, "shared_runners_setting", shared_runners_setting)
        if subgroup_creation_level is not None:
            pulumi.set(__self__, "subgroup_creation_level", subgroup_creation_level)
        if two_factor_grace_period is not None:
            pulumi.set(__self__, "two_factor_grace_period", two_factor_grace_period)
        if visibility_level is not None:
            pulumi.set(__self__, "visibility_level", visibility_level)
        if web_url is not None:
            pulumi.set(__self__, "web_url", web_url)
        if wiki_access_level is not None:
            pulumi.set(__self__, "wiki_access_level", wiki_access_level)

    @_builtins.property
    @pulumi.getter(name="allowMergeOnSkippedPipeline")
    def allow_merge_on_skipped_pipeline(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        """
        return pulumi.get(self, "allow_merge_on_skipped_pipeline")

    @allow_merge_on_skipped_pipeline.setter
    def allow_merge_on_skipped_pipeline(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_merge_on_skipped_pipeline", value)

    @_builtins.property
    @pulumi.getter(name="allowedEmailDomainsLists")
    def allowed_email_domains_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        """
        return pulumi.get(self, "allowed_email_domains_lists")

    @allowed_email_domains_lists.setter
    def allowed_email_domains_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_email_domains_lists", value)

    @_builtins.property
    @pulumi.getter(name="autoDevopsEnabled")
    def auto_devops_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Default to Auto DevOps pipeline for all projects within this group.
        """
        return pulumi.get(self, "auto_devops_enabled")

    @auto_devops_enabled.setter
    def auto_devops_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_devops_enabled", value)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A local path to the avatar image to upload. **Note**: not available for imported resources.
        """
        return pulumi.get(self, "avatar")

    @avatar.setter
    def avatar(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar", value)

    @_builtins.property
    @pulumi.getter(name="avatarHash")
    def avatar_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        """
        return pulumi.get(self, "avatar_hash")

    @avatar_hash.setter
    def avatar_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar_hash", value)

    @_builtins.property
    @pulumi.getter(name="avatarUrl")
    def avatar_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the avatar image.
        """
        return pulumi.get(self, "avatar_url")

    @avatar_url.setter
    def avatar_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar_url", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Initial default branch name.
        """
        return pulumi.get(self, "default_branch")

    @default_branch.setter
    def default_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_branch", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    @_utilities.deprecated("""Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""")
    def default_branch_protection(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        """
        return pulumi.get(self, "default_branch_protection")

    @default_branch_protection.setter
    def default_branch_protection(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_branch_protection", value)

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtectionDefaults")
    def default_branch_protection_defaults(self) -> Optional[pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs']]:
        """
        The default branch protection defaults
        """
        return pulumi.get(self, "default_branch_protection_defaults")

    @default_branch_protection_defaults.setter
    def default_branch_protection_defaults(self, value: Optional[pulumi.Input['GroupDefaultBranchProtectionDefaultsArgs']]):
        pulumi.set(self, "default_branch_protection_defaults", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group's description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="emailsEnabled")
    def emails_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable email notifications.
        """
        return pulumi.get(self, "emails_enabled")

    @emails_enabled.setter
    def emails_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "emails_enabled", value)

    @_builtins.property
    @pulumi.getter(name="extraSharedRunnersMinutesLimit")
    def extra_shared_runners_minutes_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Can be set by administrators only. Additional CI/CD minutes for this group.
        """
        return pulumi.get(self, "extra_shared_runners_minutes_limit")

    @extra_shared_runners_minutes_limit.setter
    def extra_shared_runners_minutes_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "extra_shared_runners_minutes_limit", value)

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The full name of the group.
        """
        return pulumi.get(self, "full_name")

    @full_name.setter
    def full_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "full_name", value)

    @_builtins.property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The full path of the group.
        """
        return pulumi.get(self, "full_path")

    @full_path.setter
    def full_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "full_path", value)

    @_builtins.property
    @pulumi.getter(name="ipRestrictionRanges")
    def ip_restriction_ranges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        """
        return pulumi.get(self, "ip_restriction_ranges")

    @ip_restriction_ranges.setter
    def ip_restriction_ranges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_restriction_ranges", value)

    @_builtins.property
    @pulumi.getter(name="lfsEnabled")
    def lfs_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable/disable Large File Storage (LFS) for the projects in this group.
        """
        return pulumi.get(self, "lfs_enabled")

    @lfs_enabled.setter
    def lfs_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "lfs_enabled", value)

    @_builtins.property
    @pulumi.getter(name="membershipLock")
    def membership_lock(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Users cannot be added to projects in this group.
        """
        return pulumi.get(self, "membership_lock")

    @membership_lock.setter
    def membership_lock(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "membership_lock", value)

    @_builtins.property
    @pulumi.getter(name="mentionsDisabled")
    def mentions_disabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable the capability of a group from getting mentioned.
        """
        return pulumi.get(self, "mentions_disabled")

    @mentions_disabled.setter
    def mentions_disabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mentions_disabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="onlyAllowMergeIfAllDiscussionsAreResolved")
    def only_allow_merge_if_all_discussions_are_resolved(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        """
        return pulumi.get(self, "only_allow_merge_if_all_discussions_are_resolved")

    @only_allow_merge_if_all_discussions_are_resolved.setter
    def only_allow_merge_if_all_discussions_are_resolved(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_allow_merge_if_all_discussions_are_resolved", value)

    @_builtins.property
    @pulumi.getter(name="onlyAllowMergeIfPipelineSucceeds")
    def only_allow_merge_if_pipeline_succeeds(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        """
        return pulumi.get(self, "only_allow_merge_if_pipeline_succeeds")

    @only_allow_merge_if_pipeline_succeeds.setter
    def only_allow_merge_if_pipeline_succeeds(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_allow_merge_if_pipeline_succeeds", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Id of the parent group (creates a nested group).
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path of the group.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="permanentlyRemoveOnDelete")
    def permanently_remove_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        """
        return pulumi.get(self, "permanently_remove_on_delete")

    @permanently_remove_on_delete.setter
    def permanently_remove_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "permanently_remove_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="preventForkingOutsideGroup")
    def prevent_forking_outside_group(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        """
        return pulumi.get(self, "prevent_forking_outside_group")

    @prevent_forking_outside_group.setter
    def prevent_forking_outside_group(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prevent_forking_outside_group", value)

    @_builtins.property
    @pulumi.getter(name="preventSharingGroupsOutsideHierarchy")
    def prevent_sharing_groups_outside_hierarchy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        """
        return pulumi.get(self, "prevent_sharing_groups_outside_hierarchy")

    @prevent_sharing_groups_outside_hierarchy.setter
    def prevent_sharing_groups_outside_hierarchy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "prevent_sharing_groups_outside_hierarchy", value)

    @_builtins.property
    @pulumi.getter(name="projectCreationLevel")
    def project_creation_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        """
        return pulumi.get(self, "project_creation_level")

    @project_creation_level.setter
    def project_creation_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_creation_level", value)

    @_builtins.property
    @pulumi.getter(name="pushRules")
    def push_rules(self) -> Optional[pulumi.Input['GroupPushRulesArgs']]:
        """
        Push rules for the group.
        """
        return pulumi.get(self, "push_rules")

    @push_rules.setter
    def push_rules(self, value: Optional[pulumi.Input['GroupPushRulesArgs']]):
        pulumi.set(self, "push_rules", value)

    @_builtins.property
    @pulumi.getter(name="requestAccessEnabled")
    def request_access_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow users to request member access.
        """
        return pulumi.get(self, "request_access_enabled")

    @request_access_enabled.setter
    def request_access_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "request_access_enabled", value)

    @_builtins.property
    @pulumi.getter(name="requireTwoFactorAuthentication")
    def require_two_factor_authentication(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require all users in this group to setup Two-factor authentication.
        """
        return pulumi.get(self, "require_two_factor_authentication")

    @require_two_factor_authentication.setter
    def require_two_factor_authentication(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "require_two_factor_authentication", value)

    @_builtins.property
    @pulumi.getter(name="runnersToken")
    def runners_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group level registration token to use during runner setup.
        """
        return pulumi.get(self, "runners_token")

    @runners_token.setter
    def runners_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "runners_token", value)

    @_builtins.property
    @pulumi.getter(name="shareWithGroupLock")
    def share_with_group_lock(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Prevent sharing a project with another group within this group.
        """
        return pulumi.get(self, "share_with_group_lock")

    @share_with_group_lock.setter
    def share_with_group_lock(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "share_with_group_lock", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutesLimit")
    def shared_runners_minutes_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        """
        return pulumi.get(self, "shared_runners_minutes_limit")

    @shared_runners_minutes_limit.setter
    def shared_runners_minutes_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "shared_runners_minutes_limit", value)

    @_builtins.property
    @pulumi.getter(name="sharedRunnersSetting")
    def shared_runners_setting(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        """
        return pulumi.get(self, "shared_runners_setting")

    @shared_runners_setting.setter
    def shared_runners_setting(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_runners_setting", value)

    @_builtins.property
    @pulumi.getter(name="subgroupCreationLevel")
    def subgroup_creation_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        """
        return pulumi.get(self, "subgroup_creation_level")

    @subgroup_creation_level.setter
    def subgroup_creation_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subgroup_creation_level", value)

    @_builtins.property
    @pulumi.getter(name="twoFactorGracePeriod")
    def two_factor_grace_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        """
        return pulumi.get(self, "two_factor_grace_period")

    @two_factor_grace_period.setter
    def two_factor_grace_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "two_factor_grace_period", value)

    @_builtins.property
    @pulumi.getter(name="visibilityLevel")
    def visibility_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        """
        return pulumi.get(self, "visibility_level")

    @visibility_level.setter
    def visibility_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "visibility_level", value)

    @_builtins.property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Web URL of the group.
        """
        return pulumi.get(self, "web_url")

    @web_url.setter
    def web_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_url", value)

    @_builtins.property
    @pulumi.getter(name="wikiAccessLevel")
    def wiki_access_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        return pulumi.get(self, "wiki_access_level")

    @wiki_access_level.setter
    def wiki_access_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "wiki_access_level", value)


@pulumi.type_token("gitlab:index/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_merge_on_skipped_pipeline: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_email_domains_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input[Union['GroupDefaultBranchProtectionDefaultsArgs', 'GroupDefaultBranchProtectionDefaultsArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extra_shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_restriction_ranges: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 lfs_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 membership_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 mentions_disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 only_allow_merge_if_all_discussions_are_resolved: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_allow_merge_if_pipeline_succeeds: Optional[pulumi.Input[_builtins.bool]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.int]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_remove_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_forking_outside_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_sharing_groups_outside_hierarchy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 push_rules: Optional[pulumi.Input[Union['GroupPushRulesArgs', 'GroupPushRulesArgsDict']]] = None,
                 request_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 share_with_group_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 subgroup_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 visibility_level: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.Group("example",
            name="example",
            path="example",
            description="An example group")
        # Create a project in the example group
        example_project = gitlab.Project("example",
            name="example",
            description="An example project",
            namespace_id=example.id)
        # Group with custom push rules
        example_two = gitlab.Group("example-two",
            name="example-two",
            path="example-two",
            description="An example group with push rules",
            push_rules={
                "author_email_regex": "@example\\\\.com$",
                "commit_committer_check": True,
                "member_check": True,
                "prevent_secrets": True,
            })
        # Group with custom default branch protection defaults
        example_three = gitlab.Group("example-three",
            name="example-three",
            path="example-three",
            description="An example group with default branch protection defaults",
            default_branch_protection_defaults={
                "allowed_to_pushes": ["developer"],
                "allow_force_push": True,
                "allowed_to_merges": [
                    "developer",
                    "maintainer",
                ],
                "developer_can_initial_push": True,
            })
        # Group with custom default branch protection defaults
        example_four = gitlab.Group("example-four",
            name="example-four",
            path="example-four",
            description="An example group with default branch protection defaults",
            default_branch_protection_defaults={
                "allowed_to_pushes": ["no one"],
                "allow_force_push": True,
                "allowed_to_merges": ["no one"],
                "developer_can_initial_push": True,
            })
        # Group with a default branch name specified
        example_five = gitlab.Group("example-five",
            name="example",
            path="example",
            default_branch="develop",
            description="An example group with a default branch name")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group`. For example:

        terraform

        import {

          to = gitlab_group.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/group:Group You can import a group state using `<resource> <id>`. The
        ```

        `id` can be whatever the [details of a group][details_of_a_group] api takes for

        its `:id` value, so for example:

        ```sh
        $ pulumi import gitlab:index/group:Group example example
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_merge_on_skipped_pipeline: Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_domains_lists: A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Default to Auto DevOps pipeline for all projects within this group.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        :param pulumi.Input[_builtins.str] default_branch: Initial default branch name.
        :param pulumi.Input[_builtins.int] default_branch_protection: See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        :param pulumi.Input[Union['GroupDefaultBranchProtectionDefaultsArgs', 'GroupDefaultBranchProtectionDefaultsArgsDict']] default_branch_protection_defaults: The default branch protection defaults
        :param pulumi.Input[_builtins.str] description: The group's description.
        :param pulumi.Input[_builtins.bool] emails_enabled: Enable email notifications.
        :param pulumi.Input[_builtins.int] extra_shared_runners_minutes_limit: Can be set by administrators only. Additional CI/CD minutes for this group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_restriction_ranges: A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        :param pulumi.Input[_builtins.bool] lfs_enabled: Enable/disable Large File Storage (LFS) for the projects in this group.
        :param pulumi.Input[_builtins.bool] membership_lock: Users cannot be added to projects in this group.
        :param pulumi.Input[_builtins.bool] mentions_disabled: Disable the capability of a group from getting mentioned.
        :param pulumi.Input[_builtins.str] name: The name of the group.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_all_discussions_are_resolved: Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_pipeline_succeeds: Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] parent_id: Id of the parent group (creates a nested group).
        :param pulumi.Input[_builtins.str] path: The path of the group.
        :param pulumi.Input[_builtins.bool] permanently_remove_on_delete: Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        :param pulumi.Input[_builtins.bool] prevent_forking_outside_group: Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        :param pulumi.Input[_builtins.bool] prevent_sharing_groups_outside_hierarchy: Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        :param pulumi.Input[_builtins.str] project_creation_level: Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        :param pulumi.Input[Union['GroupPushRulesArgs', 'GroupPushRulesArgsDict']] push_rules: Push rules for the group.
        :param pulumi.Input[_builtins.bool] request_access_enabled: Allow users to request member access.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: Require all users in this group to setup Two-factor authentication.
        :param pulumi.Input[_builtins.bool] share_with_group_lock: Prevent sharing a project with another group within this group.
        :param pulumi.Input[_builtins.int] shared_runners_minutes_limit: Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        :param pulumi.Input[_builtins.str] shared_runners_setting: Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        :param pulumi.Input[_builtins.str] subgroup_creation_level: Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        :param pulumi.Input[_builtins.str] visibility_level: The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        :param pulumi.Input[_builtins.str] wiki_access_level: The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.Group("example",
            name="example",
            path="example",
            description="An example group")
        # Create a project in the example group
        example_project = gitlab.Project("example",
            name="example",
            description="An example project",
            namespace_id=example.id)
        # Group with custom push rules
        example_two = gitlab.Group("example-two",
            name="example-two",
            path="example-two",
            description="An example group with push rules",
            push_rules={
                "author_email_regex": "@example\\\\.com$",
                "commit_committer_check": True,
                "member_check": True,
                "prevent_secrets": True,
            })
        # Group with custom default branch protection defaults
        example_three = gitlab.Group("example-three",
            name="example-three",
            path="example-three",
            description="An example group with default branch protection defaults",
            default_branch_protection_defaults={
                "allowed_to_pushes": ["developer"],
                "allow_force_push": True,
                "allowed_to_merges": [
                    "developer",
                    "maintainer",
                ],
                "developer_can_initial_push": True,
            })
        # Group with custom default branch protection defaults
        example_four = gitlab.Group("example-four",
            name="example-four",
            path="example-four",
            description="An example group with default branch protection defaults",
            default_branch_protection_defaults={
                "allowed_to_pushes": ["no one"],
                "allow_force_push": True,
                "allowed_to_merges": ["no one"],
                "developer_can_initial_push": True,
            })
        # Group with a default branch name specified
        example_five = gitlab.Group("example-five",
            name="example",
            path="example",
            default_branch="develop",
            description="An example group with a default branch name")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group`. For example:

        terraform

        import {

          to = gitlab_group.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/group:Group You can import a group state using `<resource> <id>`. The
        ```

        `id` can be whatever the [details of a group][details_of_a_group] api takes for

        its `:id` value, so for example:

        ```sh
        $ pulumi import gitlab:index/group:Group example example
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_merge_on_skipped_pipeline: Optional[pulumi.Input[_builtins.bool]] = None,
                 allowed_email_domains_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
                 default_branch_protection_defaults: Optional[pulumi.Input[Union['GroupDefaultBranchProtectionDefaultsArgs', 'GroupDefaultBranchProtectionDefaultsArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 extra_shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_restriction_ranges: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 lfs_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 membership_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 mentions_disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 only_allow_merge_if_all_discussions_are_resolved: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_allow_merge_if_pipeline_succeeds: Optional[pulumi.Input[_builtins.bool]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.int]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 permanently_remove_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_forking_outside_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 prevent_sharing_groups_outside_hierarchy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 push_rules: Optional[pulumi.Input[Union['GroupPushRulesArgs', 'GroupPushRulesArgsDict']]] = None,
                 request_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
                 share_with_group_lock: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 shared_runners_setting: Optional[pulumi.Input[_builtins.str]] = None,
                 subgroup_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
                 two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
                 visibility_level: Optional[pulumi.Input[_builtins.str]] = None,
                 wiki_access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["allow_merge_on_skipped_pipeline"] = allow_merge_on_skipped_pipeline
            __props__.__dict__["allowed_email_domains_lists"] = allowed_email_domains_lists
            __props__.__dict__["auto_devops_enabled"] = auto_devops_enabled
            __props__.__dict__["avatar"] = avatar
            __props__.__dict__["avatar_hash"] = avatar_hash
            __props__.__dict__["default_branch"] = default_branch
            __props__.__dict__["default_branch_protection"] = default_branch_protection
            __props__.__dict__["default_branch_protection_defaults"] = default_branch_protection_defaults
            __props__.__dict__["description"] = description
            __props__.__dict__["emails_enabled"] = emails_enabled
            __props__.__dict__["extra_shared_runners_minutes_limit"] = extra_shared_runners_minutes_limit
            __props__.__dict__["ip_restriction_ranges"] = ip_restriction_ranges
            __props__.__dict__["lfs_enabled"] = lfs_enabled
            __props__.__dict__["membership_lock"] = membership_lock
            __props__.__dict__["mentions_disabled"] = mentions_disabled
            __props__.__dict__["name"] = name
            __props__.__dict__["only_allow_merge_if_all_discussions_are_resolved"] = only_allow_merge_if_all_discussions_are_resolved
            __props__.__dict__["only_allow_merge_if_pipeline_succeeds"] = only_allow_merge_if_pipeline_succeeds
            __props__.__dict__["parent_id"] = parent_id
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            __props__.__dict__["permanently_remove_on_delete"] = permanently_remove_on_delete
            __props__.__dict__["prevent_forking_outside_group"] = prevent_forking_outside_group
            __props__.__dict__["prevent_sharing_groups_outside_hierarchy"] = prevent_sharing_groups_outside_hierarchy
            __props__.__dict__["project_creation_level"] = project_creation_level
            __props__.__dict__["push_rules"] = push_rules
            __props__.__dict__["request_access_enabled"] = request_access_enabled
            __props__.__dict__["require_two_factor_authentication"] = require_two_factor_authentication
            __props__.__dict__["share_with_group_lock"] = share_with_group_lock
            __props__.__dict__["shared_runners_minutes_limit"] = shared_runners_minutes_limit
            __props__.__dict__["shared_runners_setting"] = shared_runners_setting
            __props__.__dict__["subgroup_creation_level"] = subgroup_creation_level
            __props__.__dict__["two_factor_grace_period"] = two_factor_grace_period
            __props__.__dict__["visibility_level"] = visibility_level
            __props__.__dict__["wiki_access_level"] = wiki_access_level
            __props__.__dict__["avatar_url"] = None
            __props__.__dict__["full_name"] = None
            __props__.__dict__["full_path"] = None
            __props__.__dict__["runners_token"] = None
            __props__.__dict__["web_url"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["runnersToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Group, __self__).__init__(
            'gitlab:index/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_merge_on_skipped_pipeline: Optional[pulumi.Input[_builtins.bool]] = None,
            allowed_email_domains_lists: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            auto_devops_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            avatar: Optional[pulumi.Input[_builtins.str]] = None,
            avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
            avatar_url: Optional[pulumi.Input[_builtins.str]] = None,
            default_branch: Optional[pulumi.Input[_builtins.str]] = None,
            default_branch_protection: Optional[pulumi.Input[_builtins.int]] = None,
            default_branch_protection_defaults: Optional[pulumi.Input[Union['GroupDefaultBranchProtectionDefaultsArgs', 'GroupDefaultBranchProtectionDefaultsArgsDict']]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            emails_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            extra_shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
            full_name: Optional[pulumi.Input[_builtins.str]] = None,
            full_path: Optional[pulumi.Input[_builtins.str]] = None,
            ip_restriction_ranges: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            lfs_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            membership_lock: Optional[pulumi.Input[_builtins.bool]] = None,
            mentions_disabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            only_allow_merge_if_all_discussions_are_resolved: Optional[pulumi.Input[_builtins.bool]] = None,
            only_allow_merge_if_pipeline_succeeds: Optional[pulumi.Input[_builtins.bool]] = None,
            parent_id: Optional[pulumi.Input[_builtins.int]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            permanently_remove_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            prevent_forking_outside_group: Optional[pulumi.Input[_builtins.bool]] = None,
            prevent_sharing_groups_outside_hierarchy: Optional[pulumi.Input[_builtins.bool]] = None,
            project_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
            push_rules: Optional[pulumi.Input[Union['GroupPushRulesArgs', 'GroupPushRulesArgsDict']]] = None,
            request_access_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            require_two_factor_authentication: Optional[pulumi.Input[_builtins.bool]] = None,
            runners_token: Optional[pulumi.Input[_builtins.str]] = None,
            share_with_group_lock: Optional[pulumi.Input[_builtins.bool]] = None,
            shared_runners_minutes_limit: Optional[pulumi.Input[_builtins.int]] = None,
            shared_runners_setting: Optional[pulumi.Input[_builtins.str]] = None,
            subgroup_creation_level: Optional[pulumi.Input[_builtins.str]] = None,
            two_factor_grace_period: Optional[pulumi.Input[_builtins.int]] = None,
            visibility_level: Optional[pulumi.Input[_builtins.str]] = None,
            web_url: Optional[pulumi.Input[_builtins.str]] = None,
            wiki_access_level: Optional[pulumi.Input[_builtins.str]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_merge_on_skipped_pipeline: Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_email_domains_lists: A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        :param pulumi.Input[_builtins.bool] auto_devops_enabled: Default to Auto DevOps pipeline for all projects within this group.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        :param pulumi.Input[_builtins.str] avatar_url: The URL of the avatar image.
        :param pulumi.Input[_builtins.str] default_branch: Initial default branch name.
        :param pulumi.Input[_builtins.int] default_branch_protection: See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        :param pulumi.Input[Union['GroupDefaultBranchProtectionDefaultsArgs', 'GroupDefaultBranchProtectionDefaultsArgsDict']] default_branch_protection_defaults: The default branch protection defaults
        :param pulumi.Input[_builtins.str] description: The group's description.
        :param pulumi.Input[_builtins.bool] emails_enabled: Enable email notifications.
        :param pulumi.Input[_builtins.int] extra_shared_runners_minutes_limit: Can be set by administrators only. Additional CI/CD minutes for this group.
        :param pulumi.Input[_builtins.str] full_name: The full name of the group.
        :param pulumi.Input[_builtins.str] full_path: The full path of the group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_restriction_ranges: A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        :param pulumi.Input[_builtins.bool] lfs_enabled: Enable/disable Large File Storage (LFS) for the projects in this group.
        :param pulumi.Input[_builtins.bool] membership_lock: Users cannot be added to projects in this group.
        :param pulumi.Input[_builtins.bool] mentions_disabled: Disable the capability of a group from getting mentioned.
        :param pulumi.Input[_builtins.str] name: The name of the group.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_all_discussions_are_resolved: Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] only_allow_merge_if_pipeline_succeeds: Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] parent_id: Id of the parent group (creates a nested group).
        :param pulumi.Input[_builtins.str] path: The path of the group.
        :param pulumi.Input[_builtins.bool] permanently_remove_on_delete: Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        :param pulumi.Input[_builtins.bool] prevent_forking_outside_group: Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        :param pulumi.Input[_builtins.bool] prevent_sharing_groups_outside_hierarchy: Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        :param pulumi.Input[_builtins.str] project_creation_level: Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        :param pulumi.Input[Union['GroupPushRulesArgs', 'GroupPushRulesArgsDict']] push_rules: Push rules for the group.
        :param pulumi.Input[_builtins.bool] request_access_enabled: Allow users to request member access.
        :param pulumi.Input[_builtins.bool] require_two_factor_authentication: Require all users in this group to setup Two-factor authentication.
        :param pulumi.Input[_builtins.str] runners_token: The group level registration token to use during runner setup.
        :param pulumi.Input[_builtins.bool] share_with_group_lock: Prevent sharing a project with another group within this group.
        :param pulumi.Input[_builtins.int] shared_runners_minutes_limit: Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        :param pulumi.Input[_builtins.str] shared_runners_setting: Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        :param pulumi.Input[_builtins.str] subgroup_creation_level: Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        :param pulumi.Input[_builtins.int] two_factor_grace_period: Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        :param pulumi.Input[_builtins.str] visibility_level: The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        :param pulumi.Input[_builtins.str] web_url: Web URL of the group.
        :param pulumi.Input[_builtins.str] wiki_access_level: The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["allow_merge_on_skipped_pipeline"] = allow_merge_on_skipped_pipeline
        __props__.__dict__["allowed_email_domains_lists"] = allowed_email_domains_lists
        __props__.__dict__["auto_devops_enabled"] = auto_devops_enabled
        __props__.__dict__["avatar"] = avatar
        __props__.__dict__["avatar_hash"] = avatar_hash
        __props__.__dict__["avatar_url"] = avatar_url
        __props__.__dict__["default_branch"] = default_branch
        __props__.__dict__["default_branch_protection"] = default_branch_protection
        __props__.__dict__["default_branch_protection_defaults"] = default_branch_protection_defaults
        __props__.__dict__["description"] = description
        __props__.__dict__["emails_enabled"] = emails_enabled
        __props__.__dict__["extra_shared_runners_minutes_limit"] = extra_shared_runners_minutes_limit
        __props__.__dict__["full_name"] = full_name
        __props__.__dict__["full_path"] = full_path
        __props__.__dict__["ip_restriction_ranges"] = ip_restriction_ranges
        __props__.__dict__["lfs_enabled"] = lfs_enabled
        __props__.__dict__["membership_lock"] = membership_lock
        __props__.__dict__["mentions_disabled"] = mentions_disabled
        __props__.__dict__["name"] = name
        __props__.__dict__["only_allow_merge_if_all_discussions_are_resolved"] = only_allow_merge_if_all_discussions_are_resolved
        __props__.__dict__["only_allow_merge_if_pipeline_succeeds"] = only_allow_merge_if_pipeline_succeeds
        __props__.__dict__["parent_id"] = parent_id
        __props__.__dict__["path"] = path
        __props__.__dict__["permanently_remove_on_delete"] = permanently_remove_on_delete
        __props__.__dict__["prevent_forking_outside_group"] = prevent_forking_outside_group
        __props__.__dict__["prevent_sharing_groups_outside_hierarchy"] = prevent_sharing_groups_outside_hierarchy
        __props__.__dict__["project_creation_level"] = project_creation_level
        __props__.__dict__["push_rules"] = push_rules
        __props__.__dict__["request_access_enabled"] = request_access_enabled
        __props__.__dict__["require_two_factor_authentication"] = require_two_factor_authentication
        __props__.__dict__["runners_token"] = runners_token
        __props__.__dict__["share_with_group_lock"] = share_with_group_lock
        __props__.__dict__["shared_runners_minutes_limit"] = shared_runners_minutes_limit
        __props__.__dict__["shared_runners_setting"] = shared_runners_setting
        __props__.__dict__["subgroup_creation_level"] = subgroup_creation_level
        __props__.__dict__["two_factor_grace_period"] = two_factor_grace_period
        __props__.__dict__["visibility_level"] = visibility_level
        __props__.__dict__["web_url"] = web_url
        __props__.__dict__["wiki_access_level"] = wiki_access_level
        return Group(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowMergeOnSkippedPipeline")
    def allow_merge_on_skipped_pipeline(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow merging merge requests when the pipeline is skipped. Only applies when only*allow*merge*if*pipeline_succeeds is true. Premium and Ultimate only.
        """
        return pulumi.get(self, "allow_merge_on_skipped_pipeline")

    @_builtins.property
    @pulumi.getter(name="allowedEmailDomainsLists")
    def allowed_email_domains_lists(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of email address domains to allow group access. Will be concatenated together into a comma separated string.
        """
        return pulumi.get(self, "allowed_email_domains_lists")

    @_builtins.property
    @pulumi.getter(name="autoDevopsEnabled")
    def auto_devops_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Default to Auto DevOps pipeline for all projects within this group.
        """
        return pulumi.get(self, "auto_devops_enabled")

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A local path to the avatar image to upload. **Note**: not available for imported resources.
        """
        return pulumi.get(self, "avatar")

    @_builtins.property
    @pulumi.getter(name="avatarHash")
    def avatar_hash(self) -> pulumi.Output[_builtins.str]:
        """
        The hash of the avatar image. Use `filesha256("path/to/avatar.png")` whenever possible. **Note**: this is used to trigger an update of the avatar. If it's not given, but an avatar is given, the avatar will be updated each time.
        """
        return pulumi.get(self, "avatar_hash")

    @_builtins.property
    @pulumi.getter(name="avatarUrl")
    def avatar_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the avatar image.
        """
        return pulumi.get(self, "avatar_url")

    @_builtins.property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Initial default branch name.
        """
        return pulumi.get(self, "default_branch")

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtection")
    @_utilities.deprecated("""Deprecated in GitLab 17.0, due for removal in v5 of the API. Use default_branch_protection_defaults instead.""")
    def default_branch_protection(self) -> pulumi.Output[_builtins.int]:
        """
        See https://docs.gitlab.com/api/groups/#options-for-default*branch*protection. Valid values are: `0`, `1`, `2`, `3`, `4`.
        """
        return pulumi.get(self, "default_branch_protection")

    @_builtins.property
    @pulumi.getter(name="defaultBranchProtectionDefaults")
    def default_branch_protection_defaults(self) -> pulumi.Output['outputs.GroupDefaultBranchProtectionDefaults']:
        """
        The default branch protection defaults
        """
        return pulumi.get(self, "default_branch_protection_defaults")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The group's description.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="emailsEnabled")
    def emails_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable email notifications.
        """
        return pulumi.get(self, "emails_enabled")

    @_builtins.property
    @pulumi.getter(name="extraSharedRunnersMinutesLimit")
    def extra_shared_runners_minutes_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Can be set by administrators only. Additional CI/CD minutes for this group.
        """
        return pulumi.get(self, "extra_shared_runners_minutes_limit")

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> pulumi.Output[_builtins.str]:
        """
        The full name of the group.
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> pulumi.Output[_builtins.str]:
        """
        The full path of the group.
        """
        return pulumi.get(self, "full_path")

    @_builtins.property
    @pulumi.getter(name="ipRestrictionRanges")
    def ip_restriction_ranges(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of IP addresses or subnet masks to restrict group access. Will be concatenated together into a comma separated string. Only allowed on top level groups.
        """
        return pulumi.get(self, "ip_restriction_ranges")

    @_builtins.property
    @pulumi.getter(name="lfsEnabled")
    def lfs_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable/disable Large File Storage (LFS) for the projects in this group.
        """
        return pulumi.get(self, "lfs_enabled")

    @_builtins.property
    @pulumi.getter(name="membershipLock")
    def membership_lock(self) -> pulumi.Output[_builtins.bool]:
        """
        Users cannot be added to projects in this group.
        """
        return pulumi.get(self, "membership_lock")

    @_builtins.property
    @pulumi.getter(name="mentionsDisabled")
    def mentions_disabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Disable the capability of a group from getting mentioned.
        """
        return pulumi.get(self, "mentions_disabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the group.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="onlyAllowMergeIfAllDiscussionsAreResolved")
    def only_allow_merge_if_all_discussions_are_resolved(self) -> pulumi.Output[_builtins.bool]:
        """
        Only allow merging merge requests when all discussions are resolved. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        """
        return pulumi.get(self, "only_allow_merge_if_all_discussions_are_resolved")

    @_builtins.property
    @pulumi.getter(name="onlyAllowMergeIfPipelineSucceeds")
    def only_allow_merge_if_pipeline_succeeds(self) -> pulumi.Output[_builtins.bool]:
        """
        Only allow merging merge requests if the pipeline succeeds. When enabled for a group, applies to all projects in the group. Premium and Ultimate only.
        """
        return pulumi.get(self, "only_allow_merge_if_pipeline_succeeds")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Output[_builtins.int]:
        """
        Id of the parent group (creates a nested group).
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        The path of the group.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="permanentlyRemoveOnDelete")
    def permanently_remove_on_delete(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the group should be permanently removed during a `delete` operation. This only works with subgroups. Must be configured via an `apply` before the `destroy` is run.
        """
        return pulumi.get(self, "permanently_remove_on_delete")

    @_builtins.property
    @pulumi.getter(name="preventForkingOutsideGroup")
    def prevent_forking_outside_group(self) -> pulumi.Output[_builtins.bool]:
        """
        Defaults to false. When enabled, users can not fork projects from this group to external namespaces.
        """
        return pulumi.get(self, "prevent_forking_outside_group")

    @_builtins.property
    @pulumi.getter(name="preventSharingGroupsOutsideHierarchy")
    def prevent_sharing_groups_outside_hierarchy(self) -> pulumi.Output[_builtins.bool]:
        """
        Defaults to false. When enabled, users cannot invite other groups outside of the top-level group’s hierarchy. This option is only available for top-level groups.
        """
        return pulumi.get(self, "prevent_sharing_groups_outside_hierarchy")

    @_builtins.property
    @pulumi.getter(name="projectCreationLevel")
    def project_creation_level(self) -> pulumi.Output[_builtins.str]:
        """
        Determine if developers can create projects in the group. Valid values are: `noone`, `owner`, `maintainer`, `developer`, `administrator`
        """
        return pulumi.get(self, "project_creation_level")

    @_builtins.property
    @pulumi.getter(name="pushRules")
    def push_rules(self) -> pulumi.Output['outputs.GroupPushRules']:
        """
        Push rules for the group.
        """
        return pulumi.get(self, "push_rules")

    @_builtins.property
    @pulumi.getter(name="requestAccessEnabled")
    def request_access_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Allow users to request member access.
        """
        return pulumi.get(self, "request_access_enabled")

    @_builtins.property
    @pulumi.getter(name="requireTwoFactorAuthentication")
    def require_two_factor_authentication(self) -> pulumi.Output[_builtins.bool]:
        """
        Require all users in this group to setup Two-factor authentication.
        """
        return pulumi.get(self, "require_two_factor_authentication")

    @_builtins.property
    @pulumi.getter(name="runnersToken")
    def runners_token(self) -> pulumi.Output[_builtins.str]:
        """
        The group level registration token to use during runner setup.
        """
        return pulumi.get(self, "runners_token")

    @_builtins.property
    @pulumi.getter(name="shareWithGroupLock")
    def share_with_group_lock(self) -> pulumi.Output[_builtins.bool]:
        """
        Prevent sharing a project with another group within this group.
        """
        return pulumi.get(self, "share_with_group_lock")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersMinutesLimit")
    def shared_runners_minutes_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Can be set by administrators only. Maximum number of monthly CI/CD minutes for this group. Can be nil (default; inherit system default), 0 (unlimited), or > 0.
        """
        return pulumi.get(self, "shared_runners_minutes_limit")

    @_builtins.property
    @pulumi.getter(name="sharedRunnersSetting")
    def shared_runners_setting(self) -> pulumi.Output[_builtins.str]:
        """
        Enable or disable shared runners for a group’s subgroups and projects. Valid values are: `enabled`, `disabled_and_overridable`, `disabled_and_unoverridable`, `disabled_with_override`.
        """
        return pulumi.get(self, "shared_runners_setting")

    @_builtins.property
    @pulumi.getter(name="subgroupCreationLevel")
    def subgroup_creation_level(self) -> pulumi.Output[_builtins.str]:
        """
        Allowed to create subgroups. Valid values are: `owner`, `maintainer`.
        """
        return pulumi.get(self, "subgroup_creation_level")

    @_builtins.property
    @pulumi.getter(name="twoFactorGracePeriod")
    def two_factor_grace_period(self) -> pulumi.Output[_builtins.int]:
        """
        Defaults to 48. Time before Two-factor authentication is enforced (in hours).
        """
        return pulumi.get(self, "two_factor_grace_period")

    @_builtins.property
    @pulumi.getter(name="visibilityLevel")
    def visibility_level(self) -> pulumi.Output[_builtins.str]:
        """
        The group's visibility. Can be `private`, `internal`, or `public`. Valid values are: `private`, `internal`, `public`.
        """
        return pulumi.get(self, "visibility_level")

    @_builtins.property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> pulumi.Output[_builtins.str]:
        """
        Web URL of the group.
        """
        return pulumi.get(self, "web_url")

    @_builtins.property
    @pulumi.getter(name="wikiAccessLevel")
    def wiki_access_level(self) -> pulumi.Output[_builtins.str]:
        """
        The group's wiki access level. Only available on Premium and Ultimate plans. Valid values are `disabled`, `private`, `enabled`.
        """
        return pulumi.get(self, "wiki_access_level")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectPackageDependencyProxyArgs', 'ProjectPackageDependencyProxy']

@pulumi.input_type
class ProjectPackageDependencyProxyArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 maven_external_registry_password: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_url: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectPackageDependencyProxy resource.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the dependency proxy is enabled for packages.
        :param pulumi.Input[_builtins.str] maven_external_registry_password: The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        :param pulumi.Input[_builtins.str] maven_external_registry_url: The URL of the external Maven registry.
        :param pulumi.Input[_builtins.str] maven_external_registry_username: The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        """
        pulumi.set(__self__, "project", project)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if maven_external_registry_password is not None:
            pulumi.set(__self__, "maven_external_registry_password", maven_external_registry_password)
        if maven_external_registry_url is not None:
            pulumi.set(__self__, "maven_external_registry_url", maven_external_registry_url)
        if maven_external_registry_username is not None:
            pulumi.set(__self__, "maven_external_registry_username", maven_external_registry_username)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the dependency proxy is enabled for packages.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryPassword")
    def maven_external_registry_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        """
        return pulumi.get(self, "maven_external_registry_password")

    @maven_external_registry_password.setter
    def maven_external_registry_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maven_external_registry_password", value)

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryUrl")
    def maven_external_registry_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the external Maven registry.
        """
        return pulumi.get(self, "maven_external_registry_url")

    @maven_external_registry_url.setter
    def maven_external_registry_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maven_external_registry_url", value)

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryUsername")
    def maven_external_registry_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        """
        return pulumi.get(self, "maven_external_registry_username")

    @maven_external_registry_username.setter
    def maven_external_registry_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maven_external_registry_username", value)


@pulumi.input_type
class _ProjectPackageDependencyProxyState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 maven_external_registry_password: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_url: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_username: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectPackageDependencyProxy resources.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the dependency proxy is enabled for packages.
        :param pulumi.Input[_builtins.str] maven_external_registry_password: The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        :param pulumi.Input[_builtins.str] maven_external_registry_url: The URL of the external Maven registry.
        :param pulumi.Input[_builtins.str] maven_external_registry_username: The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if maven_external_registry_password is not None:
            pulumi.set(__self__, "maven_external_registry_password", maven_external_registry_password)
        if maven_external_registry_url is not None:
            pulumi.set(__self__, "maven_external_registry_url", maven_external_registry_url)
        if maven_external_registry_username is not None:
            pulumi.set(__self__, "maven_external_registry_username", maven_external_registry_username)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the dependency proxy is enabled for packages.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryPassword")
    def maven_external_registry_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        """
        return pulumi.get(self, "maven_external_registry_password")

    @maven_external_registry_password.setter
    def maven_external_registry_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maven_external_registry_password", value)

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryUrl")
    def maven_external_registry_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the external Maven registry.
        """
        return pulumi.get(self, "maven_external_registry_url")

    @maven_external_registry_url.setter
    def maven_external_registry_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maven_external_registry_url", value)

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryUsername")
    def maven_external_registry_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        """
        return pulumi.get(self, "maven_external_registry_username")

    @maven_external_registry_username.setter
    def maven_external_registry_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "maven_external_registry_username", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)


@pulumi.type_token("gitlab:index/projectPackageDependencyProxy:ProjectPackageDependencyProxy")
class ProjectPackageDependencyProxy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 maven_external_registry_password: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_url: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_username: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectPackageDependencyProxy` resource allows managing the project-level package dependency proxy for Maven packages.

        This resource configures the external Maven registry settings for the dependency proxy, allowing packages to be cached and proxied through GitLab.

        > This resource requires GitLab Premium or Ultimate and the packages and dependency proxy features to be enabled on the GitLab instance.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationupdatedependencyproxypackagessettings)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Configure the project package dependency proxy for Maven packages
        example = gitlab.ProjectPackageDependencyProxy("example",
            project=example_gitlab_project["id"],
            enabled=True,
            maven_external_registry_url="https://repo.maven.apache.org/maven2/")
        # With authentication credentials for the external registry
        authenticated = gitlab.ProjectPackageDependencyProxy("authenticated",
            project=example_gitlab_project["id"],
            enabled=True,
            maven_external_registry_url="https://private-repo.example.com/maven/",
            maven_external_registry_username="maven_user",
            maven_external_registry_password=maven_registry_password)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_package_dependency_proxy`. For example:

        terraform

        import {

          to = gitlab_project_package_dependency_proxy.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import a project package dependency proxy using the project id. e.g. `{project-id}`

        "maven_external_registry_password" will not populate when importing, but will still

        be required in the configuration if credentials are used.

        ```sh
        $ pulumi import gitlab:index/projectPackageDependencyProxy:ProjectPackageDependencyProxy example 42
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the dependency proxy is enabled for packages.
        :param pulumi.Input[_builtins.str] maven_external_registry_password: The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        :param pulumi.Input[_builtins.str] maven_external_registry_url: The URL of the external Maven registry.
        :param pulumi.Input[_builtins.str] maven_external_registry_username: The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectPackageDependencyProxyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectPackageDependencyProxy` resource allows managing the project-level package dependency proxy for Maven packages.

        This resource configures the external Maven registry settings for the dependency proxy, allowing packages to be cached and proxied through GitLab.

        > This resource requires GitLab Premium or Ultimate and the packages and dependency proxy features to be enabled on the GitLab instance.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationupdatedependencyproxypackagessettings)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Configure the project package dependency proxy for Maven packages
        example = gitlab.ProjectPackageDependencyProxy("example",
            project=example_gitlab_project["id"],
            enabled=True,
            maven_external_registry_url="https://repo.maven.apache.org/maven2/")
        # With authentication credentials for the external registry
        authenticated = gitlab.ProjectPackageDependencyProxy("authenticated",
            project=example_gitlab_project["id"],
            enabled=True,
            maven_external_registry_url="https://private-repo.example.com/maven/",
            maven_external_registry_username="maven_user",
            maven_external_registry_password=maven_registry_password)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_package_dependency_proxy`. For example:

        terraform

        import {

          to = gitlab_project_package_dependency_proxy.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import a project package dependency proxy using the project id. e.g. `{project-id}`

        "maven_external_registry_password" will not populate when importing, but will still

        be required in the configuration if credentials are used.

        ```sh
        $ pulumi import gitlab:index/projectPackageDependencyProxy:ProjectPackageDependencyProxy example 42
        ```

        :param str resource_name: The name of the resource.
        :param ProjectPackageDependencyProxyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectPackageDependencyProxyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 maven_external_registry_password: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_url: Optional[pulumi.Input[_builtins.str]] = None,
                 maven_external_registry_username: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectPackageDependencyProxyArgs.__new__(ProjectPackageDependencyProxyArgs)

            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["maven_external_registry_password"] = None if maven_external_registry_password is None else pulumi.Output.secret(maven_external_registry_password)
            __props__.__dict__["maven_external_registry_url"] = maven_external_registry_url
            __props__.__dict__["maven_external_registry_username"] = maven_external_registry_username
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["mavenExternalRegistryPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectPackageDependencyProxy, __self__).__init__(
            'gitlab:index/projectPackageDependencyProxy:ProjectPackageDependencyProxy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            maven_external_registry_password: Optional[pulumi.Input[_builtins.str]] = None,
            maven_external_registry_url: Optional[pulumi.Input[_builtins.str]] = None,
            maven_external_registry_username: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectPackageDependencyProxy':
        """
        Get an existing ProjectPackageDependencyProxy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Indicates whether the dependency proxy is enabled for packages.
        :param pulumi.Input[_builtins.str] maven_external_registry_password: The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        :param pulumi.Input[_builtins.str] maven_external_registry_url: The URL of the external Maven registry.
        :param pulumi.Input[_builtins.str] maven_external_registry_username: The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectPackageDependencyProxyState.__new__(_ProjectPackageDependencyProxyState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["maven_external_registry_password"] = maven_external_registry_password
        __props__.__dict__["maven_external_registry_url"] = maven_external_registry_url
        __props__.__dict__["maven_external_registry_username"] = maven_external_registry_username
        __props__.__dict__["project"] = project
        return ProjectPackageDependencyProxy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the dependency proxy is enabled for packages.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryPassword")
    def maven_external_registry_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The password to authenticate with the external Maven registry. Must be set together with `maven_external_registry_username`. Cannot be imported.
        """
        return pulumi.get(self, "maven_external_registry_password")

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryUrl")
    def maven_external_registry_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the external Maven registry.
        """
        return pulumi.get(self, "maven_external_registry_url")

    @_builtins.property
    @pulumi.getter(name="mavenExternalRegistryUsername")
    def maven_external_registry_username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The username to authenticate with the external Maven registry. Must be set together with `maven_external_registry_password`.
        """
        return pulumi.get(self, "maven_external_registry_username")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

